==> elasticsearch-java-7.15.0-sources.jar: co/elastic/clients/elasticsearch/_types/SearchType.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types;

import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.util.StringEnum;

@JsonpDeserializable
public enum SearchType implements StringEnum {
	/**
	 * Documents are scored using local term and document frequencies for the shard.
	 * This is usually faster but less accurate.
	 */
	QueryThenFetch("query_then_fetch"),
	/**
	 * Documents are scored using global term and document frequencies across all
	 * shards. This is usually slower but more accurate.
	 */
	DfsQueryThenFetch("dfs_query_then_fetch");

	private final String jsonValue;

	SearchType(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final StringEnum.Deserializer<SearchType> _DESERIALIZER = new StringEnum.Deserializer<>(
			SearchType.values());
}

==> elasticsearch-java-7.16.3-sources.jar: co/elastic/clients/elasticsearch/_types/SearchType.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types;

import co.elastic.clients.json.JsonEnum;
import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;

/**
 *
 * @see <a href=
 *      "https://github.com/elastic/elasticsearch-specification/tree/98036c3/specification/_types/common.ts#L243-L248">API
 *      specification</a>
 */
@JsonpDeserializable
public enum SearchType implements JsonEnum {
	/**
	 * Documents are scored using local term and document frequencies for the shard.
	 * This is usually faster but less accurate.
	 */
	QueryThenFetch("query_then_fetch"),

	/**
	 * Documents are scored using global term and document frequencies across all
	 * shards. This is usually slower but more accurate.
	 */
	DfsQueryThenFetch("dfs_query_then_fetch"),

	;

	private final String jsonValue;

	SearchType(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final JsonEnum.Deserializer<SearchType> _DESERIALIZER = new JsonEnum.Deserializer<>(
			SearchType.values());
}
